sub-.deflist.Rd
Subset a deflist object
# S3 method for class 'deflist' x[i]
A deflist object.
Indices or names of the elements to be retrieved.
A list containing the elements at the specified indices or names in the deflist object.
deflist