Skip to contents

Retrieve an element from a deflist object

Usage

# S3 method for class 'deflist'
x[[i]]

Arguments

x

A deflist object.

i

Index or name of the element to be retrieved.

Value

The element at the specified index or name in the deflist object.