sub-sub-.deflist.Rd
Retrieve an element from a deflist object
# S3 method for class 'deflist' x[[i]]
A deflist object.
Index or name of the element to be retrieved.
The element at the specified index or name in the deflist object.